==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/es.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "App Dashboard",
    "Show something" : "Mostrar algo",
    "Customize" : "Personalizar",
    "Edit widgets" : "Editar widgets",
    "Get more widgets from the app store" : "Conseguir más widgets desde la app store",
    "Change background image" : "Cambiar imagen de fondo",
    "Weather service" : "Servicio climatológico",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Por privacidad, los datos climatológicos son solicitados por tu servidor Nextcloud en tu nombre de tal forma que el servicio no recibe información personal.",
    "Weather data from Met.no" : "Datos climatológicos de Met.no",
    "geocoding with Nominatim" : "geocoding con Nominatim",
    "elevation data from OpenTopoData" : "datos de elevación de OpenTopoData",
    "Weather" : "El tiempo",
    "Status" : "Estado",
    "Good evening, {name}" : "Buenas tardes, {name}",
    "Good evening" : "Buenas tardes",
    "Good afternoon, {name}" : "Buenas tardes, {name}",
    "Good afternoon" : "Buenas tardes",
    "Good morning, {name}" : "Buenos días, {name}",
    "Good morning" : "Buenos días",
    "Good night, {name}" : "Buenas noches, {name}",
    "Good night" : "Buenas noches",
    "Pick from files" : "Escoger desde los archivos",
    "Default images" : "Imágenes predeterminadas",
    "Plain background" : "Fondo liso",
    "Insert from {productName}" : "Insertar desde {productName}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/es.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "App Dashboard",
    "Show something" : "Mostrar algo",
    "Customize" : "Personalizar",
    "Edit widgets" : "Editar widgets",
    "Get more widgets from the app store" : "Conseguir más widgets desde la app store",
    "Change background image" : "Cambiar imagen de fondo",
    "Weather service" : "Servicio climatológico",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Por privacidad, los datos climatológicos son solicitados por tu servidor Nextcloud en tu nombre de tal forma que el servicio no recibe información personal.",
    "Weather data from Met.no" : "Datos climatológicos de Met.no",
    "geocoding with Nominatim" : "geocoding con Nominatim",
    "elevation data from OpenTopoData" : "datos de elevación de OpenTopoData",
    "Weather" : "El tiempo",
    "Status" : "Estado",
    "Good morning" : "Buenos días",
    "Good morning, {name}" : "Buenos días, {name}",
    "Good afternoon" : "Buenas tardes",
    "Good afternoon, {name}" : "Buenas tardes, {name}",
    "Good evening" : "Buenas tardes",
    "Good evening, {name}" : "Buenas tardes, {name}",
    "Hello" : "Hola",
    "Hello, {name}" : "Hola, {name}",
    "Pick from Files" : "Elegir de Archivos",
    "Default images" : "Imágenes predeterminadas",
    "Plain background" : "Fondo liso",
    "Insert from {productName}" : "Insertar desde {productName}",
    "Good night, {name}" : "Buenas noches, {name}",
    "Good night" : "Buenas noches",
    "Pick from files" : "Escoger desde los archivos"
},
"nplurals=2; plural=(n != 1);");
